#ifndef KWLANSETTINGSDLG_H
#define KWLANSETTINGSDLG_H
/** KWlan
 *
 *  This File is part of KWlan, a network Manager for KDE.
 *  KWlan is distributed under LGPL license.
 *
 *	@author Thomas Michel <tom.michel@arcor.de>
 */

#include "kwlansettings.h"

class QString;
class Configuration;

class KWlanSettingsDlg : public KWlanSettings
{
  Q_OBJECT

public:
  KWlanSettingsDlg(QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
  ~KWlanSettingsDlg();
  void setConfiguraton(Configuration *conf);
  /*$PUBLIC_FUNCTIONS$*/

public slots:
  /*$PUBLIC_SLOTS$*/
  virtual void          enableWpaNoQuestion(int state);
  virtual void          Cancel();
  virtual void          Ok();

protected:
  /*$PROTECTED_FUNCTIONS$*/

protected slots:
  /*$PROTECTED_SLOTS$*/
private:
   Configuration *m_configuration;

};

#endif

